@@ -38,6 +38,7 @@ _service_endpoints_template = {
     'sts': '{proto}://{host}:4592',
     'iam': '{proto}://{host}:4593',
     'rds': '{proto}://{host}:4594',
+    'rds-data': '{proto}://{host}:4594',
     'cloudsearch': '{proto}://{host}:4595',
     'swf': '{proto}://{host}:4596',
     'ec2': '{proto}://{host}:4597',
@@ -55,7 +56,11 @@ _service_endpoints_template = {
     'sagemaker': '{proto}://{host}:4609',
     'sagemaker-runtime': '{proto}://{host}:4609',
     'ecr': '{proto}://{host}:4610',
-    'qldb': '{proto}://{host}:4611'
+    'qldb': '{proto}://{host}:4611',
+    'cloudtrail': '{proto}://{host}:4612',
+    'glacier': '{proto}://{host}:4613',
+    'batch': '{proto}://{host}:4614',
+    'organizations': '{proto}://{host}:4615'
 }
 
 
